#
# spec file for package python-proselint
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname proselint
Name:           python-proselint
Version:        0.13.0
Release:        3.4
Summary:        A linter for prose
License:        BSD-3-Clause
URL:            https://github.com/amperser/proselint
Source:         https://github.com/amperser/%{modname}/archive/refs/tags/%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click
Requires:       python-dbm
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module dbm}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
proselint is a linter for English prose. (A linter is a computer
program that, like a spell checker, scans through a document and
analyzes it.)

Proselint is a command-line utility that can be integrated into
existing tools.

%prep
%autosetup -p1 -n proselint-%{version}

sed -i -e '/^#!\//, 1d' proselint/*.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/proselint
%{python_expand %fdupes %{buildroot}%{$python_sitelib}}

%post
%python_install_alternative proselint

%postun
%python_uninstall_alternative proselint

%check
%pytest

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.md
%python_alternative %{_bindir}/proselint
%{python_sitelib}/proselint/
%{python_sitelib}/proselint-%{version}.dist-info

%changelog
* Fri Sep  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove future requirement, not required.
- Switch to autosetup.
- Drop python2 leftovers.
* Thu Oct 20 2022 pgajdos@suse.com
- python-six is not required
* Fri Feb 11 2022 Benedikt Fein <benedikt.fein@gmail.com>
- Update to 0.13.0
  - made memoize safe for both arguments and keyword arguments
  - now exports decorators that wrap meta-checks
- Update to 0.12.0
  - make am_pm checks case-sensitive
  - added --dump-config and --dump-default-config CLI arguments
  - now exports proselint.config.default
  - proselint.tools.lint now takes a config object instead of
    using load_options
- Proselint no longer uses a proselintrc config file.
  Remove no longer needed commands from the spec.
* Mon Jul 12 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.11.3:
  - fix package bundling to include proselintrc (#1195)
* Thu Jul  8 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.11.2:
  - correct false positives in lexical_illusions.misc
  - fix package metadata and pypi upload (hotfix release)
  - add warning for missing corpus
  - reduce false positives for uncomparables.misc
  - correct "attorney and not a republic" mondegreen
  - correct unbound line and column in error printing
  - fix false positive in misc.but
  - add --config CLI argument
  - add exceptions for proselint.tools.existence_check
  - use regex for lexical_illusions.misc
  - implement project-wide proselintrc
  Removed upstreamed patches:
  - disable-empty-test.patch
  - remove_nose.patch
  - test-use-sys-executable.patch
* Sun Aug 16 2020 Matej Cepl <mcepl@suse.com>
- Replace the sed command from the previous commit with
  the proper patch remove_nose.patch and send it upstream
  (gh#amperser/proselint#1097).
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Replace unittest+nose with pytest
- Tidy spec
* Wed May  6 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use python dbm dependency instead of legacy gdbm
* Fri Mar  8 2019 John Vandenberg <jayvdb@gmail.com>
- Add test-use-sys-executable.patch to avoid invoking Python 3 CLI
  during Python 2 tests.
* Thu Feb 14 2019 John Vandenberg <jayvdb@gmail.com>
- Fix invocation of test suite to run the tests
- Add Recommends for python2-gdbm, and BuildRequires to activate
  the tests related to gdbm
- Add disable-empty-test.patch to remove unused test module
- Update to v0.10.2
  * Include tests in source package
- from v0.10.1
  * Support use as pre-commit hook
- from v0.10.0
  * Update dependencies to latest
  * Add support for reading from stdin with the CLI
  * Use pytest, not Nose, on Travis
- from v0.9.0
  * Add new plugins to README
  * Update dependencies
  * Comply with XDG spec
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Remove rhetoric part from description.
* Thu May 24 2018 toddrme2178@gmail.com
- Spec file cleanups
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version for v0.8.0
